<?php
$TRANSLATIONS = array(
"Documents" => "Asiakirjat",
"Can't create document" => "Asiakirjan luominen epäonnistui",
"You don't have permission to rename this document" => "Oikeutesi eivät riitä nimeämään tätä asiakirjaa uudelleen",
"Directory saved successfully." => "Kansio tallennettiin onnistuneesti.",
"An error occurred while changing directory." => "Virhe kansiota vaihtaessa.",
"Saved" => "Tallennettu",
"Format filter server is down or misconfigured" => "Muotosuodatuspalvelin ei ole käytettävissä tai sen asetukset ovat väärin",
"Conversion failed. Check log for details." => "Muuntaminen epäonnistui. Katso lisätietoja lokista.",
"Saving..." => "Tallennetaan...",
"Failed to load documents." => "Virhe ladattaessa dokumentteja.",
"No documents were found. Upload or create a document to get started!" => "Asiakirjoja ei löytynyt. Lähetä tai luo asiakirja aloittaaksesi!",
"No connection to server. Trying to reconnect." => "Ei yhteyttä palvelimeen. Yritetään yhdistää uudelleen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Tältä sivulta poistuminen muokkaustilassa saattaa aiheuttaa tallentamatonta tietoa. Käytä sivulta poistumisen sijaan \"Sulje\"-painiketta.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Asiakirjan lataaminen epäonnistui. Yritä avata asiakirja erillisellä odt:tä tukevalla sovelluksella. Tämä virhe voi myös tarkoittaa, että asiakirja ei ole enää jaettu tai asiakirja on poistettu äskettäin.",
"Save" => "Tallenna",
"Loading documents..." => "Ladataan asiakirjoja...",
"'.' is an invalid file name." => "'.' on virheellinen nimi tiedostolle.",
"File name cannot be empty." => "Tiedoston nimi ei voi olla tyhjä.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Virheellinen nimi, merkit '\\', '/', '<', '>', ':', '\"', '|', '?' ja '*' eivät ole sallittuja.",
"Align Left" => "Tasaa vasemmalle",
"Alignment" => "Tasaus",
"Align Right" => "Tasaa oikealle",
"Annotate" => "Kommentoi",
"Background" => "Tausta",
"Bold" => "Lihavoitu",
"Bottom" => "Alas",
"Cancel" => "Peru",
"Center" => "Keskelle",
"Clone" => "Kloonaa",
"Clone this Style" => "Kloonaa tämä tyyli",
"Close" => "Sulje",
"Color" => "Väri",
"Create" => "Luo",
"Decrease Indent" => "Vähennä sisennystä",
"Default Style" => "Oletustyyli",
"Delete" => "Poista",
"Family" => "Perhe",
"Font" => "Kirjasin",
"Font Effects" => "Kirjasintehosteet",
"Format" => "Muotoilu",
"Increase Indent" => "Lisää sisennystä",
"Insert Image" => "Lisää kuva",
"Invite Members" => "Kutsu jäseniä",
"Italic" => "Kursivoitu",
"Justified" => "Tasattu",
"Justify" => "Tasaa",
"Left" => "Vasemmalle",
"Loading" => "Ladataan",
"Members" => "Jäsenet",
"New Name:" => "Uusi nimi:",
"OK" => "OK",
"Open" => "Avaa",
"Options" => "Valinnat",
"Paragraph..." => "Kappale...",
"Paragraph Styles" => "Kappaletyylit",
"Redo" => "Tee uudelleen",
"Right" => "Oikealle",
"Size" => "Koko",
"Spacing" => "Välistys",
"Strikethrough" => "Yliviivattu",
"Style" => "Tyyli",
"Text" => "Teksti",
"Top" => "Ylös",
"Underline" => "Alleviivattu",
"Undo" => "Kumoa",
"Unknown Author" => "Tuntematon tekijä",
"Shared" => "Jaettu",
"Error" => "Virhe",
"Error while sharing" => "Virhe jaettaessa",
"Error while unsharing" => "Virhe jakoa peruttaessa",
"Error while changing permissions" => "Virhe oikeuksia muuttaessa",
"Shared with you and the group {group} by {owner}" => "Jaettu sinun ja ryhmän {group} kanssa käyttäjän {owner} toimesta",
"Shared with you by {owner}" => "Jaettu kanssasi käyttäjän {owner} toimesta",
"Share with users or groups …" => "Jaa käyttäjien tai ryhmien kanssa…",
"Share with users, groups or remote users …" => "Jaa käyttäjien, ryhmien tai etäkäyttäjien kanssa…",
"Share" => "Jaa",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Jaa toisia ownCloud-järjestelmiä käyttävien kesken käyttäen syntaksia käyttäjätunnus@esimerkki.fi/owncloud",
"Share link" => "Jaa linkki",
"The public link will expire no later than {days} days after it is created" => "Julkinen linkki vanhenee {days} päivän jälkeen sen luomisesta",
"Link" => "Linkki",
"Password protect" => "Suojaa salasanalla",
"Password" => "Salasana",
"Choose a password for the public link" => "Valitse salasana julkiselle linkille",
"Allow editing" => "Salli muokkaus",
"Email link to person" => "Lähetä linkki sähköpostitse",
"Send" => "Lähetä",
"Set expiration date" => "Aseta päättymispäivä",
"Expiration" => "Erääntyminen",
"Expiration date" => "Päättymispäivä",
"An error occured. Please try again" => "Tapahtui virhe. Yritä myöhemmin uudestaan",
"Adding user..." => "Lisätään käyttäjä...",
"group" => "ryhmä",
"remote" => "etä",
"Resharing is not allowed" => "Jakaminen uudelleen ei ole salittu",
"Shared in {item} with {user}" => "{item} on jaettu {user} kanssa",
"Unshare" => "Peru jakaminen",
"notify by email" => "ilmoita sähköpostitse",
"can share" => "jaa",
"can edit" => "voi muokata",
"access control" => "Pääsyn hallinta",
"create" => "luo",
"change" => "muuta",
"delete" => "poista",
"Password protected" => "Salasanasuojattu",
"Error unsetting expiration date" => "Virhe purettaessa eräpäivää",
"Error setting expiration date" => "Virhe päättymispäivää asettaessa",
"Sending ..." => "Lähetetään...",
"Email sent" => "Sähköposti lähetetty",
"Warning" => "Varoitus",
"Edit" => "Muokkaa",
"guest" => "vieras",
"MS Word support (requires openOffice/libreOffice)" => "MS Word -tuki (vaatimuksena openOffice/libreOffice)",
"Local" => "Paikallinen",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice on asennettu tälle palvelimelle. Polku suoritettavaan tiedostoon määritetään tiedoston config.php kohdassa preview_libreoffice_path",
"External" => "Ulkoinen",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice on asennettu erillisille palvelimelle, joka tarjoaa muotosuodatuspalvelimen ominaisuudet",
"Disabled" => "Ei käytössä",
"No MS Word support" => "Ei MS Word -tukea",
"Server URL" => "Palvelimen osoite",
"Apply and test" => "Toteuta ja testaa",
"New document" => "Uusi asiakirja",
"Upload (max. %s)" => "Lähetys (enintään %s)",
"Upload" => "Lähetä",
"Save new documents to" => "Uusien asiakirjojen tallennussijainti",
"Wrong password. Please retry." => "Väärä salasana. Yritä uudelleen.",
"Guest %s" => "Vieras %s",
"Advanced feature-set" => "Tarkemmat toiminto-asetukset",
"(Unstable)" => "(Epävakaa)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
